@@ -34,8 +34,8 @@ class ShopifyBook(QuerySchema):
     gid: str
     isbn: str
     title: str
-    author: str
-    price: Decimal
+    author: t.Optional[str]
+    price: t.Optional[Decimal]
     subtitle: t.Optional[str]
     description: t.Optional[str]
     publisher: t.Optional[str]
